==> jc-1.4.0.tar.gz: java/awt/ColorPaintContext__24ColorRaster.h <==
// class java.awt.ColorPaintContext$ColorRaster

// class file dependencies
// @dep_class a2eacab6e28dd325 java_awt_ColorPaintContext__24ColorRaster
// @dep_class 136b10f57a43bf20 java_awt_image_Raster
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_image_Raster

#include "java/awt/image/Raster.h"

#ifndef _JC_java_awt_ColorPaintContext__24ColorRaster_H_
#define _JC_java_awt_ColorPaintContext__24ColorRaster_H_

// Forward structure declarations
struct _jc_java_awt_ColorPaintContext$object;
struct _jc_java_awt_image_ColorModel$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_awt_ColorPaintContext__24ColorRaster$sub_refs	_jc_java_awt_ColorPaintContext__24ColorRaster$sub_refs;
typedef struct _jc_java_awt_ColorPaintContext__24ColorRaster$sub_nonrefs	_jc_java_awt_ColorPaintContext__24ColorRaster$sub_nonrefs;
typedef struct _jc_java_awt_ColorPaintContext__24ColorRaster$refs	_jc_java_awt_ColorPaintContext__24ColorRaster$refs;
typedef struct _jc_java_awt_ColorPaintContext__24ColorRaster$nonrefs	_jc_java_awt_ColorPaintContext__24ColorRaster$nonrefs;
typedef struct _jc_java_awt_ColorPaintContext__24ColorRaster$object	_jc_java_awt_ColorPaintContext__24ColorRaster$object;

typedef const struct _jc_java_awt_ColorPaintContext__24ColorRaster$vmethods	_jc_java_awt_ColorPaintContext__24ColorRaster$vmethods;
typedef const struct _jc_java_awt_ColorPaintContext__24ColorRaster$vtable	_jc_java_awt_ColorPaintContext__24ColorRaster$vtable;
typedef const struct _jc_java_awt_ColorPaintContext__24ColorRaster$vtype	_jc_java_awt_ColorPaintContext__24ColorRaster$vtype;

// Constructors
extern void _jc_java_awt_ColorPaintContext__24ColorRaster$method$_init$98aa58e6c127a732(_jc_env *, struct _jc_java_awt_ColorPaintContext__24ColorRaster$object *, struct _jc_java_awt_ColorPaintContext$object *, struct _jc_java_awt_image_ColorModel$object *, jint, jint, jint, jint, jint);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_awt_ColorPaintContext__24ColorRaster$method$multiplyData$732341d9779c8385(_jc_env *, struct _jc_java_awt_ColorPaintContext__24ColorRaster$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_java_awt_ColorPaintContext__24ColorRaster$method_info$multiplyData$732341d9779c8385;

// Virtual methods structure
struct _jc_java_awt_ColorPaintContext__24ColorRaster$vmethods {
	struct _jc_java_lang_Object$object	*(*multiplyData$732341d9779c8385)(_jc_env *, struct _jc_java_awt_ColorPaintContext__24ColorRaster$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, jint);
};

// Vtable
struct _jc_java_awt_ColorPaintContext__24ColorRaster$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_image_Raster$vmethods	java_awt_image_Raster;
	_jc_java_awt_ColorPaintContext__24ColorRaster$vmethods	java_awt_ColorPaintContext__24ColorRaster;
};

// Vtype
struct _jc_java_awt_ColorPaintContext__24ColorRaster$vtype {
	_jc_type			type;
	_jc_java_awt_ColorPaintContext__24ColorRaster$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_ColorPaintContext__24ColorRaster$sub_refs {
	struct _jc_java_awt_ColorPaintContext$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_ColorPaintContext__24ColorRaster$refs {
    _jc_java_awt_ColorPaintContext__24ColorRaster$sub_refs	java_awt_ColorPaintContext__24ColorRaster;
    _jc_java_awt_image_Raster$sub_refs	java_awt_image_Raster;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_ColorPaintContext__24ColorRaster$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_ColorPaintContext__24ColorRaster$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_image_Raster$sub_nonrefs	java_awt_image_Raster;
    _jc_java_awt_ColorPaintContext__24ColorRaster$sub_nonrefs	java_awt_ColorPaintContext__24ColorRaster;
};

// Object instance structure
struct _jc_java_awt_ColorPaintContext__24ColorRaster$object {
	_jc_java_awt_ColorPaintContext__24ColorRaster$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_ColorPaintContext__24ColorRaster$vtype	*vtype;
	_jc_java_awt_ColorPaintContext__24ColorRaster$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_ColorPaintContext__24ColorRaster$vtype _jc_java_awt_ColorPaintContext__24ColorRaster$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_ColorPaintContext__24ColorRaster, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_ColorPaintContext__24ColorRaster$class_object;

#endif	/* _JC_java_awt_ColorPaintContext__24ColorRaster_H_ */

==> jc-1.4.6.tar.gz: java/awt/ColorPaintContext__24ColorRaster.h <==
// class java.awt.ColorPaintContext$ColorRaster

// class file dependencies
// @dep_class a2eacab6e28dd325 java_awt_ColorPaintContext__24ColorRaster
// @dep_class 136b10f57a43bf20 java_awt_image_Raster
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_image_Raster

#include "java/awt/image/Raster.h"

#ifndef _JC_java_awt_ColorPaintContext__24ColorRaster_H_
#define _JC_java_awt_ColorPaintContext__24ColorRaster_H_

// Forward structure declarations
struct _jc_java_awt_ColorPaintContext$object;
struct _jc_java_awt_image_ColorModel$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_awt_ColorPaintContext__24ColorRaster$sub_refs	_jc_java_awt_ColorPaintContext__24ColorRaster$sub_refs;
typedef struct _jc_java_awt_ColorPaintContext__24ColorRaster$sub_nonrefs	_jc_java_awt_ColorPaintContext__24ColorRaster$sub_nonrefs;
typedef struct _jc_java_awt_ColorPaintContext__24ColorRaster$refs	_jc_java_awt_ColorPaintContext__24ColorRaster$refs;
typedef struct _jc_java_awt_ColorPaintContext__24ColorRaster$nonrefs	_jc_java_awt_ColorPaintContext__24ColorRaster$nonrefs;
typedef struct _jc_java_awt_ColorPaintContext__24ColorRaster$object	_jc_java_awt_ColorPaintContext__24ColorRaster$object;

typedef const struct _jc_java_awt_ColorPaintContext__24ColorRaster$vmethods	_jc_java_awt_ColorPaintContext__24ColorRaster$vmethods;
typedef const struct _jc_java_awt_ColorPaintContext__24ColorRaster$vtable	_jc_java_awt_ColorPaintContext__24ColorRaster$vtable;
typedef const struct _jc_java_awt_ColorPaintContext__24ColorRaster$vtype	_jc_java_awt_ColorPaintContext__24ColorRaster$vtype;

// Constructors
extern void _jc_java_awt_ColorPaintContext__24ColorRaster$method$_init$98aa58e6c127a732(_jc_env *, struct _jc_java_awt_ColorPaintContext__24ColorRaster$object *, struct _jc_java_awt_ColorPaintContext$object *, struct _jc_java_awt_image_ColorModel$object *, jint, jint, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_awt_ColorPaintContext__24ColorRaster$method$multiplyData$732341d9779c8385(_jc_env *, struct _jc_java_awt_ColorPaintContext__24ColorRaster$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_ColorPaintContext__24ColorRaster$method_info$multiplyData$732341d9779c8385;

// Virtual methods structure
struct _jc_java_awt_ColorPaintContext__24ColorRaster$vmethods {
	struct _jc_java_lang_Object$object	*(*multiplyData$732341d9779c8385)(_jc_env *, struct _jc_java_awt_ColorPaintContext__24ColorRaster$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_ColorPaintContext__24ColorRaster$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_image_Raster$vmethods	java_awt_image_Raster;
	_jc_java_awt_ColorPaintContext__24ColorRaster$vmethods	java_awt_ColorPaintContext__24ColorRaster;
};

// Vtype
struct _jc_java_awt_ColorPaintContext__24ColorRaster$vtype {
	_jc_type			type;
	_jc_java_awt_ColorPaintContext__24ColorRaster$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_ColorPaintContext__24ColorRaster$sub_refs {
	struct _jc_java_awt_ColorPaintContext$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_ColorPaintContext__24ColorRaster$refs {
    _jc_java_awt_ColorPaintContext__24ColorRaster$sub_refs	java_awt_ColorPaintContext__24ColorRaster;
    _jc_java_awt_image_Raster$sub_refs	java_awt_image_Raster;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_ColorPaintContext__24ColorRaster$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_ColorPaintContext__24ColorRaster$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_image_Raster$sub_nonrefs	java_awt_image_Raster;
    _jc_java_awt_ColorPaintContext__24ColorRaster$sub_nonrefs	java_awt_ColorPaintContext__24ColorRaster;
};

// Object instance structure
struct _jc_java_awt_ColorPaintContext__24ColorRaster$object {
	_jc_java_awt_ColorPaintContext__24ColorRaster$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_ColorPaintContext__24ColorRaster$vtype	*vtype;
	_jc_java_awt_ColorPaintContext__24ColorRaster$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_ColorPaintContext__24ColorRaster$vtype _jc_java_awt_ColorPaintContext__24ColorRaster$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_ColorPaintContext__24ColorRaster, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_ColorPaintContext__24ColorRaster$class_object;

#endif	/* _JC_java_awt_ColorPaintContext__24ColorRaster_H_ */
